Citing and Referencing
======================

[![](https://zenodo.org/badge/141922866.svg)](https://zenodo.org/badge/latestdoi/141922866)


Reference
---------
If you would like to cite or reference Glider Tools, please use:

Gregor, L., Ryan-Keogh, T. J., Nicholson, S.-A., du Plessis, M., Giddy, I., & Swart, S. (2019). GliderTools: A Python Toolbox for Processing Underwater Glider Data. Frontiers in Marine Science, 6(December), 1–13. https://doi.org/10.3389/fmars.2019.00738


Authors and contributors
------------------------

Authors and people who have contributed to the development. Not necessarily on the paper.
